/*
  $Id: registers.h 687 2006-01-26 12:18:44Z jens $

  Copyright (C) 2001-2006 Jens Thoms Toerring
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
  To contact the author send email to: jt@toerring.de
*/


/* This structure contains the addresses of registers of the TNT4882 chip
   to be read from */

typedef struct TNT4882_Register_Adresses TNT4882_Register_Adresses_t;

struct TNT4882_Register_Adresses {
	unsigned char  *DIR;          /*  0  Data In Register                */
	unsigned char  *dont_touch_1; /*  1                                  */
	unsigned char  *ISR1;         /*  2  Interrupt Status 1 Register     */
	unsigned char  *dont_touch_3; /*  3                                  */
	unsigned char  *ISR2;         /*  4  Interrupt Status 2 Register     */
	unsigned char  *dont_touch_5; /*  5                                  */
	unsigned char  *SPSR;         /*  6  Serial Poll Status Register     */
	unsigned char  *dont_touch_7; /*  7                                  */
	unsigned char  *ADSR;         /*  8  Address Status Register         */
	unsigned char  *CNT2;         /*  9  Count 2 Register                */
	unsigned char  *CPTR;         /*  A  Command Pass Through Register   */
	unsigned char  *CNT3;         /*  B  Count 3 Register                */
	unsigned char  *ADR0;         /*  C  Address 0 Register              */
	unsigned char  *dont_touch_D; /*  D                                  */
	unsigned char  *ADR1;         /*  E  Address 1 Register              */
	unsigned char  *dont_touch_F; /*  F                                  */
	unsigned char  *STS1;         /* 10  Status 1 Register               */
	unsigned char  *DSR;          /* 11  DIO Status Register             */
	unsigned char  *IMR3;         /* 12  Interrupt Mask 3 Register       */
	unsigned char  *dont_touch_13;/* 13                                  */
	unsigned char  *CNT0;         /* 14  Count 0 Register                */
	unsigned char  *dont_touch_15;/* 15                                  */
	unsigned char  *CNT1;         /* 16  Count 1 Register                */
	unsigned char  *CSR;          /* 17  Chip Signature Register         */
	unsigned char  *FIFOB;        /* 18  FIFO B Register                 */
	unsigned char  *FIFOA;        /* 19  FIFO A Register                 */
	unsigned char  *ISR3;         /* 1A  Interrupt Status Register 3     */
	unsigned char  *SASR;         /* 1B  Source/Acceptor Status Register */
	unsigned char  *STS2;         /* 1C  Status Register 2               */
	unsigned char  *ISR0;         /* 1D  Interrupt Status Register 0     */
	unsigned char  *TIMER;        /* 1E  Timer Register                  */
	unsigned char  *BSR;          /* 1F  Bus Status Register             */
};


/* Names of the corresponding writable registers */

#define CDOR   DIR                    /*  1  Command/Data Out register       */
#define IMR1   ISR1                   /*  2  Interrupt Mask Register 1       */
#define IMR2   ISR2                   /*  4  Interrupt Mask Register 2       */
#define ACCWR  dont_touch_5           /*  5  Accessory Write Register        */
#define SPMR   SPSR                   /*  6  Serial Poll Mode Register       */
#define INTR   dont_touch_7           /*  7  Board Interrupt Register        */
#define ADMR   ADSR                   /*  8  Address Mode Register           */
#define AUXMR  CPTR                   /*  A  Auxiliary Mode Register         */
#define ADR    ADR0                   /*  C  Address Register                */
#define HSSEL  dont_touch_D           /*  D  Handshake Select Register       */
#define EOSR   ADR1                   /*  E  End-of-String Register          */
#define CFG    STS1                   /* 10  Configuration Register          */
#define SH_CNT DSR                    /* 11  SH_CNT Register                 */
#define HIER   dont_touch_13          /* 13  High-Speed Enable Register      */
#define MISC   dont_touch_15          /* 15  Miscellaneous Register          */
#define KEYREG CSR                    /* 17  Key Control Register            */
#define CCR    ISR3                   /* 1A  Carry Cycle Register            */
#define DCR    SASR                   /* 1B  DIO Control Register            */
#define CMDR   STS2                   /* 1C  Command Register                */
#define IMR0   ISR0                   /* 1D  Interrupt Mask Register 0       */
#define BCR    BSR                    /* 1F  Bus Control Register            */


/* Structure for storing the state of the writable registers (most of them
   can't be read, so there's no way to find out their states) */

typedef struct TNT4882_Register_Contents TNT4882_Register_Contents_t;

struct TNT4882_Register_Contents {
	unsigned char imr1;
	unsigned char imr2;
	unsigned char accwr;
	unsigned char spmr;
	unsigned char intr;
	unsigned char admr;
	unsigned char ppr;
	unsigned char auxra;
	unsigned char auxrb;
	unsigned char auxre;
	unsigned char auxrf;
	unsigned char auxrg;
	unsigned char auxri;
	unsigned char auxrj;
	unsigned char hssel;
	unsigned char eosr;
	unsigned char cfg;
	unsigned char pt1;
	unsigned char t17;
	unsigned char t12;
	unsigned char t13;
	unsigned char imr3;
	unsigned char hier;
	unsigned char misc;
	unsigned char keyreg;
	unsigned char imr0;
	unsigned char timer;
};


/* Names for the bits in the readable registers */

#define ISR1_DI            ( 1 << 0 )   /* ISR1 */
#define ISR1_DO            ( 1 << 1 )
#define ISR1_ERR           ( 1 << 2 )
#define ISR1_DEC           ( 1 << 3 )
#define ISR1_END_RX        ( 1 << 4 )
#define ISR1_DET           ( 1 << 5 )
#define ISR1_APT           ( 1 << 6 )
#define ISR1_CPT           ( 1 << 7 )

#define ISR2_ADSC          ( 1 << 0 )   /* ISR2 */
#define ISR2_REMC          ( 1 << 1 )
#define ISR2_LOKC          ( 1 << 2 )
#define ISR2_CO            ( 1 << 3 )
#define ISR2_REM           ( 1 << 4 )
#define ISR2_LOK           ( 1 << 5 )
#define ISR2_SRQ           ( 1 << 6 )
#define ISR2_INT           ( 1 << 7 )

#define SPSR_PEND          ( 1 << 6 )   /* SPSR */

#define ADSR_MJMN          ( 1 << 0 )   /* ADSR */
#define ADSR_TA            ( 1 << 1 )
#define ADSR_LA            ( 1 << 2 )
#define ADSR_TPAS          ( 1 << 3 )
#define ADSR_LPAS          ( 1 << 4 )
#define ADSR_SPMS          ( 1 << 5 )
#define ADSR_NATN          ( 1 << 6 )
#define ADSR_CIC           ( 1 << 7 )

#define ADR1_EOI           ( 1 << 7 )   /* ADR1 */

#define STS1_GSYNC         ( 1 << 0 )   /* STS1 */
#define STS1_HALT          ( 1 << 1 )
#define STS1_DAV           ( 1 << 2 )
#define STS1_STOP          ( 1 << 3 )
#define STS1_DRQ           ( 1 << 4 )
#define STS1_IN            ( 1 << 5 )
#define STS1_SC            ( 1 << 6 )
#define STS1_DONE          ( 1 << 7 )

#define CSR_MODE           ( 1 << 2 )   /* CSR */
#define CSR_KEY_DQ         ( 1 << 3 )
#define CSR_V0             ( 1 << 4 )
#define CSR_V1             ( 1 << 5 )
#define CSR_V2             ( 1 << 6 )
#define CSR_V3             ( 1 << 7 )
#define CSR_SIGNATURE      ( CSR_V0 | CSR_V1 | CSR_V2 | CSR_V3 )

#define ISR3_DONE          ( 1 << 0 )   /* ISR3 */
#define ISR3_TLCINT        ( 1 << 1 )
#define ISR3_NEF           ( 1 << 2 )
#define ISR3_NFF           ( 1 << 3 )
#define ISR3_STOP          ( 1 << 4 )
#define ISR3_SRQI_CIC      ( 1 << 5 )
#define ISR3_INTSRC2       ( 1 << 6 )
#define ISR3_INT           ( 1 << 7 )

#define SASR_SH1B          ( 1 << 0 )   /* SASR */
#define SASR_SH1A          ( 1 << 1 )
#define SASR_ACRDY         ( 1 << 2 )
#define SASR_ADHS          ( 1 << 3 )
#define SASR_ANHS2         ( 1 << 4 )
#define SASR_ANHS1         ( 1 << 5 )
#define SASR_AEHS          ( 1 << 6 )
#define SASR_nba           ( 1 << 7 )

#define STS2_BEFN          ( 1 << 0 )   /* STS2 */
#define STS2_BFFN          ( 1 << 1 )
#define STS2_AEFN          ( 1 << 2 )
#define STS2_AFFN          ( 1 << 3 )
#define STS2_16_8N         ( 1 << 6 )

#define ISR0_SYNC          ( 1 << 0 )   /* ISR0 */
#define ISR0_TO            ( 1 << 1 )
#define ISR0_ATNI          ( 1 << 2 )
#define ISR0_IFCI          ( 1 << 3 )
#define ISR0_EOS           ( 1 << 4 )
#define ISR0_NL            ( 1 << 5 )
#define ISR0_STBO          ( 1 << 6 )
#define ISR0_nba           ( 1 << 7 )

#define BSR_REN            ( 1 << 0 )   /* BSR */
#define BSR_IFC            ( 1 << 1 )
#define BSR_SRQ            ( 1 << 2 )
#define BSR_EOI            ( 1 << 3 )
#define BSR_NRFD           ( 1 << 4 )
#define BSR_NDAC           ( 1 << 5 )
#define BSR_DAV            ( 1 << 6 )
#define BSR_ATN            ( 1 << 7 )


/* Names for the bits in the readable and writable registers */

#define IMR3_DONE_IE       ( 1 << 0 )   /* IMR3 */
#define IMR3_TLCINT_IE     ( 1 << 1 )
#define IMR3_NEF_IE        ( 1 << 2 )
#define IMR3_NFF_IE        ( 1 << 3 )
#define IMR3_STOP_IE       ( 1 << 4 )
#define IMR3_SRQI_CIC_IE   ( 1 << 5 )
#define IMR3_INTSRC2_IE    ( 1 << 6 )
#define IMR3_INT           ( 1 << 7 )


/* Names for the bits in the writable registers */

#define IMR1_DI_IE         ( 1 << 0 )   /* IMR1 */
#define IMR1_DO_IE         ( 1 << 1 )
#define IMR1_ERR_IE        ( 1 << 2 )
#define IMR1_DEC_IE        ( 1 << 3 )
#define IMR1_END_IE        ( 1 << 4 )
#define IMR1_DET_IE        ( 1 << 5 )
#define IMR1_APT_IE        ( 1 << 6 )
#define IMR1_CPT_IE        ( 1 << 7 )

#define IMR2_ADSC_IE       ( 1 << 0 )   /* IMR2 */
#define IMR2_REMC_IE       ( 1 << 1 )
#define IMR2_LOKC_IE       ( 1 << 2 )
#define IMR2_COIE          ( 1 << 3 )
#define IMR2_DMAI          ( 1 << 4 )
#define IMR2_DMAO          ( 1 << 5 )
#define IMR2_SRQI          ( 1 << 6 )

#define ACCWR_DMAEN        ( 1 << 0 )   /* ACCWR */

#define SPMR_rsv_RQS       ( 1 << 6 )   /* SPMR */

#define INTR_INTEN         ( 1 << 0 )   /* INTR */

#define ADMR_ADM0          ( 1 << 0 )   /* ADMR */
#define ADMR_ADM1          ( 1 << 1 )
#define ADMR_lon           ( 1 << 6 )
#define ADMR_ton           ( 1 << 7 )

#define ADR_DL             ( 1 << 5 )   /* ADR */
#define ADR_DT             ( 1 << 6 )
#define ADR_ARS            ( 1 << 7 )

#define HSSEL_ONEC         ( 1 << 0 )   /* HSSEL */
#define HSSEL_NO_DMA       ( 1 << 4 )
#define HSSEL_GO2_SIDS     ( 1 << 5 )

#define CFG_16_8N          ( 1 << 0 )   /* CFG */
#define CFG_TIM_BYTN       ( 1 << 1 )
#define CFG_TMOE           ( 1 << 2 )
#define CFG_CCEN           ( 1 << 3 )
#define CFG_A_BN           ( 1 << 4 )
#define CFG_IN             ( 1 << 5 )
#define CFG_TLCHLTE        ( 1 << 6 )
#define CFG_CMD            ( 1 << 7 )

#define HIER_PMT_W_EOS     ( 1 << 0 )   /* HIER */
#define HIER_NO_TSETUP     ( 1 << 4 )
#define HIER_DGB           ( 1 << 6 )
#define HIER_DGA           ( 1 << 7 )

#define MISC_NOTS          ( 1 << 0 )   /* MISC */
#define MISC_NOAS          ( 1 << 1 )
#define MISC_WRAP          ( 1 << 2 )
#define MISC_SLOW          ( 1 << 3 )
#define MISC_HSE           ( 1 << 4 )

#define KEYREG_KEY_RST     ( 1 << 0 )   /* KEYREG */
#define KEYREG_KEY_DATA    ( 1 << 1 )
#define KEYREG_KEY_DAT_EN  ( 1 << 2 )
#define KEYREG_KEY_CLK     ( 1 << 3 )
#define KEYREG_MSTD        ( 1 << 5 )
#define KEYREG_SWAP        ( 1 << 6 )

#define IMR0_SYNC_IE       ( 1 << 0 )   /* IMR0 */
#define IMR0_TO_IE         ( 1 << 1 )
#define IMR0_ATNI_IE       ( 1 << 2 )
#define IMR0_IFCI_IE       ( 1 << 3 )
#define IMR0_BTO           ( 1 << 4 )
#define IMR0_NLEN          ( 1 << 5 )
#define IMR0_STBO_IE       ( 1 << 6 )

#define BCR_REN            ( 1 << 0 )   /* BCR */
#define BCR_IFC            ( 1 << 1 )
#define BCR_SRQ            ( 1 << 2 )
#define BCR_EOI            ( 1 << 3 )
#define BCR_NRFD           ( 1 << 4 )
#define BCR_NDAC           ( 1 << 5 )
#define BCR_DAV            ( 1 << 6 )
#define BCR_ATN            ( 1 << 7 )


/* Names for the bits in the "hidden" AUXMR registers */

#define PPR_S     	   ( 1 << 3 )   /* PPR */
#define PPR_U     	   ( 1 << 4 )

#define AUXRA_HLDA         ( 1 << 0 )   /* AUXRA */
#define AUXRA_HLDE         ( 1 << 1 )
#define AUXRA_REOS         ( 1 << 2 )
#define AUXRA_XEOS         ( 1 << 3 )
#define AUXRA_BIN          ( 1 << 4 )

#define AUXRB_CPT_ENABLE   ( 1 << 0 )   /* AUXRB */
#define AUXRB_SPEOI        ( 1 << 1 )
#define AUXRB_TRI          ( 1 << 2 )
#define AUXRB_ISS          ( 1 << 4 )

#define AUXRE_DHDC         ( 1 << 0 )   /* AUXRE */
#define AUXRE_DHDT         ( 1 << 1 )
#define AUXRE_DHADC        ( 1 << 2 )
#define AUXRE_DHADT        ( 1 << 3 )

#define AUXRF_DHALL        ( 1 << 0 )   /* AUXRF */
#define AUXRF_DHUNTL       ( 1 << 1 )
#define AUXRF_DHALA        ( 1 << 2 )
#define AUXRF_DHATA        ( 1 << 3 )

#define AUXRG_CHES         ( 1 << 0 )   /* AUXRG */
#define AUXRG_NTNL         ( 1 << 3 )

#define AUXRI_DSISB        ( 1 << 0 )   /* AUXRI */
#define AUXRI_PP2          ( 1 << 2 )
#define AUXRI_USTD         ( 1 << 3 )


/* Masks for accessing "hidden" AUXMR registers */

#define PPR         0x60
#define AUXRA       0x80
#define AUXRB       0xA0
#define AUXRE       0xC0
#define AUXRF       0xD0
#define AUXRG       0x40
#define AUXRI       0xE0
#define AUXRJ       0xF0


/* Auxiliary commands */

#define AUX_pon     0x00     	/* Immediate Execute pon              */
#define AUX_cppf    0x01     	/* Clear Parallel Poll Flag           */
#define AUX_ch_rst  0x02     	/* Chip Reset                         */
#define AUX_rhdf    0x03     	/* Finish Handshake                   */
#define AUX_trig    0x04     	/* Trigger                            */
#define AUX_crtl    0x05     	/* Clear or Pulse Return to Local     */
#define AUX_seoi    0x06     	/* Send EOI                           */
#define AUX_nval    0x07     	/* Non-Valid Sec. Command or Address  */
#define AUX_rqc     0x08        /* Request Control Command            */
#define AUX_sppf    0x09     	/* Set Parallel Poll Flag             */
#define AUX_lut     0x0B        /* Untalk Command                     */
#define AUX_lul     0x0C        /* Unlisten Command                   */
#define AUX_srtl    0x0D     	/* Set Return to Local                */
#define AUX_nbaf    0x0E        /* New Byte Available False           */
#define AUX_val     0x0F     	/* Valid Secondary Command or Address */
#define AUX_gts     0x10        /* Go To Standby                      */
#define AUX_tca     0x11        /* Take Control Asynchronously        */
#define AUX_tcs     0x12        /* Take Control Synchronously         */
#define AUX_ltn     0x13	/* Listen                             */
#define AUX_dsc     0x14	/* Disable System Control             */
#define AUX_st9914  0x15        /* Switch to Turbo+9914 Mode Command  */
#define AUX_cifc    0x16	/* Clear IFC                          */
#define AUX_cren    0x17	/* Clear REN                          */
#define AUX_reqt    0x18        /* Request rsv True                   */
#define AUX_reqf    0x19        /* Request rsv False                  */
#define AUX_tcse    0x1A	/* Take Control Synchronously on End  */
#define AUX_ltnc    0x1B	/* Listen in Continuous Mode          */
#define AUX_lun     0x1C	/* Local Unlisten                     */
#define AUX_epp     0x1D	/* Execute Parallel Poll              */
#define AUX_sifc    0x1E	/* Set IFC                            */
#define AUX_sren    0x1F	/* Set REN                            */
#define AUX_pi      0x50        /* Page-In Additional Registers       */
#define AUX_hldi    0x51        /* Holdoff Handshake Immediately      */
#define AUX_cdet    0x54        /* Clear DET (ISR1[5]r) Command       */
#define AUX_cend    0x55        /* Clear END (ISR1[4]r) Command       */
#define AUX_cdec    0x56        /* Clear DEC (ISR1[3]r) Command       */
#define AUX_cerr    0x57        /* Clear ERR (ISR1[2]r) Command       */
#define AUX_ccsrqi  0x58        /* Clear SRQI (ISR2[6]r) Command      */
#define AUX_clokc   0x59        /* Clear LOKC (ISR2[2]r) Command      */
#define AUX_cremc   0x5A        /* Clear REMC (ISR2[1]r) Command      */
#define AUX_cadsc   0x5B        /* Clear ADSC (ISR2[0]r) Command      */
#define AUX_cifci   0x5C        /* Clear IFCI (ISR0[3]r) Command      */
#define AUX_catni   0x5D        /* Clear ATNI (ISR0[2]r) Command      */
#define AUX_csync   0x5E        /* Clear SYNC (ISR0[0]r) Command      */
#define AUX_ssync   0x5F        /* Set SYNC (ISR0[0]r) Command        */


/* Name of the AUXCR register in Turbo+9914 mode and the auxilary command
   for switching to 7210 mode */

#define AUXCR       AUXMR
#define AUX_sw7210  0x99


/* Names of commands to be sent to the command register (CMDR) */

#define CLRSC       0x02        /* release system control           */
#define SETSC       0x03        /* become system controller         */
#define GO          0x04        /* clears the HALT signal           */
#define STOP        0x08        /* sets the HALT signal             */
#define RESET_FIFO  0x10        /* resets both FIFOs to empty state */
#define SOFT_RESET  0x20        /* chip software reset              */


/*
 * Local variables:
 * c-basic-offset: 8
 * c-indent-level: 8
 * c-brace-imaginary-offset: 0
 * c-brace-offset: 0
 * c-argdecl-indent: 4
 * c-label-offset: -4
 * c-continued-statement-offset: 4
 * c-continued-brace-offset: 0
 * indent-tabs-mode: t
 * tab-width: 8
 * End:
 */
