/*
  $Id: registers.h 687 2006-01-26 12:18:44Z jens $

  Copyright (C) 2001-2006 Jens Thoms Toerring
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
  To contact the author send email to:jt@toerring.de
*/


/* This structure contains the addresses of registers of the uPD7210 or
   NAT4882 (in 7210 emulation mode) to be read from */

typedef struct PCII_Register_Adresses PCII_Register_Adresses_t;

struct PCII_Register_Adresses {
	unsigned char  *DIR;
	unsigned char  *ISR1;
	unsigned char  *ISR2;
	unsigned char  *SPSR;
	unsigned char  *ADSR;
	unsigned char  *CPTR;
	unsigned char  *ADR0;
	unsigned char  *ADR1;
};


/* Define names for the corresponding write registers */

#define CDOR   DIR
#define IMR1   ISR1
#define IMR2   ISR2
#define SPMR   SPSR
#define ADMR   ADSR
#define AUXMR  CPTR
#define ADR    ADR0
#define EOSR   ADR1


/* These are names for the relevant individual bits of the read registers */

#define HR_DI      ( 1 << 0 )   /* ISR1 */
#define HR_DO      ( 1 << 1 )
#define HR_ERR     ( 1 << 2 )
#define HR_DEC     ( 1 << 3 )
#define HR_END     ( 1 << 4 )
#define HR_DET     ( 1 << 5 )
#define HR_APT     ( 1 << 6 )
#define HR_CPT     ( 1 << 7 )

#define HR_ADSC    ( 1 << 0 )   /* ISR2 */
#define HR_REMC    ( 1 << 1 )
#define HR_LOKC    ( 1 << 2 )
#define HR_CO      ( 1 << 3 )
#define HR_REM     ( 1 << 4 )
#define HR_LOK     ( 1 << 5 )
#define HR_SRQI    ( 1 << 6 )
#define HR_INT     ( 1 << 7 )

#define HR_PEND    ( 1 << 6 )   /* SPSR */

#define HR_MJMN    ( 1 << 0 )   /* ADSR */
#define HR_TA      ( 1 << 1 )
#define HR_LA      ( 1 << 2 )
#define HR_TPAS    ( 1 << 3 )
#define HR_LPAS    ( 1 << 4 )
#define HR_SPMS    ( 1 << 5 )
#define HR_NATN    ( 1 << 6 )
#define HR_CIC     ( 1 << 7 )

#define HR_EOI     ( 1 << 7 )   /* ADR1 */


/* These are names for the relevant individual bits of the write registers */

#define HR_DIIE    ( 1 << 0 )   /* IMR1 */
#define HR_DOIE    ( 1 << 1 )
#define HR_ERRIE   ( 1 << 2 )
#define HR_DECIE   ( 1 << 3 )
#define HR_ENDIE   ( 1 << 4 )
#define HR_DETIE   ( 1 << 5 )
#define HR_APTIE   ( 1 << 6 )
#define HR_CPTIE   ( 1 << 7 )

#define HR_ADSCIE  ( 1 << 0 )   /* IMR2 */
#define HR_REMCIE  ( 1 << 1 )
#define HR_LOKCIE  ( 1 << 2 )
#define HR_COIE    ( 1 << 3 )
#define HR_DMAI    ( 1 << 4 )
#define HR_DMAO    ( 1 << 5 )
#define HR_SRQIE   ( 1 << 6 )

#define HR_RSV     ( 1 << 6 )   /* SPMR */

#define HR_ADM0    ( 1 << 0 )   /* ADMR */
#define HR_ADM1    ( 1 << 1 )
#define HR_TRM0    ( 1 << 4 )
#define HR_TRM1    ( 1 << 5 )
#define HR_LON     ( 1 << 6 )
#define HR_TON     ( 1 << 7 )

#define HR_DL      ( 1 << 5 )   /* ADR */
#define HR_DT      ( 1 << 6 )
#define HR_ARS     ( 1 << 7 )

#define HR_PPRS    ( 1 << 3 )   /* PPR */
#define HR_PPRU    ( 1 << 4 )

#define HR_HLDA    ( 1 << 0 )   /* AUXRA */
#define HR_HLDE    ( 1 << 1 )
#define HR_REOS    ( 1 << 2 )
#define HR_XEOS    ( 1 << 3 )
#define HR_BIN     ( 1 << 4 )

#define HR_CPTE    ( 1 << 0 )   /* AUXRB */
#define HR_SPEOI   ( 1 << 1 )
#define HR_TRI     ( 1 << 2 )
#define HR_INV     ( 1 << 3 )
#define HR_ISS     ( 1 << 4 )


/* Masks for accessing "hidden" AUXMR registers */

#define PPR         0x60
#define AUXRA       0x80
#define AUXRB       0xA0
#define AUXRE       0xC0

#define AUXRF       0xD0        /* NAT4882 only */
#define AUXRG       0x40        /* NAT4882 only */
#define AUXRI       0xE0        /* NAT4882 only */
#define AUXRJ       0xF0        /* NAT4882 only */



/* Auxiliary commands */

#define AUX_pon     0x00     	/* Immediate Execute pon             */
#define AUX_cppf    0x01     	/* Clear Parallel Poll Flag          */
#define AUX_cr      0x02     	/* Chip Reset                        */
#define AUX_rhdf    0x03     	/* Finish Handshake                  */
#define AUX_trig    0x04     	/* Trigger                           */
#define AUX_rtl     0x05     	/* Return to local                   */
#define AUX_seoi    0x06     	/* Send EOI                          */
#define AUX_nval    0x07     	/* Non-Valid Sec. Command or Address */
#define AUX_sppf    0x09     	/* Set Parallel Poll Flag            */
#define AUX_val     0x0F     	/* Valid Secondary Command or Address*/
#define AUX_gts     0x10     	/* Go To Standby                     */
#define AUX_tca     0x11     	/* Take Control Asynchronously       */
#define AUX_tcs     0x12     	/* Take Control Synchronously        */
#define AUX_ltn     0x13     	/* Listen                            */
#define AUX_dsc     0x14     	/* Disable System Control            */
#define AUX_cifc    0x16     	/* Clear IFC                         */
#define AUX_cren    0x17     	/* Clear REN                         */
#define AUX_tcse    0x1A     	/* Take Control Synchronously on End */
#define AUX_ltnc    0x1B     	/* Listen in Continuous Mode         */
#define AUX_lun     0x1C     	/* Local Unlisten                    */
#define AUX_epp     0x1D     	/* Execute Parallel Poll             */
#define AUX_sifc    0x1E     	/* Set IFC                           */
#define AUX_sren    0x1F     	/* Set REN                           */


/*
 * Local variables:
 * c-basic-offset: 8
 * c-indent-level: 8
 * c-brace-imaginary-offset: 0
 * c-brace-offset: 0
 * c-argdecl-indent: 4
 * c-label-ofset: -4
 * c-continued-statement-offset: 4
 * c-continued-brace-offset: 0
 * indent-tabs-mode: t
 * tab-width: 8
 * End:
 */
