/*
  $Id: irq.c 737 2007-08-04 14:46:00Z jens $

  Copyright (C) 2001-2006 Jens Thoms Toerring
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
  To contact the author send email to: jt@toerring.de
*/


#include "gpib_module.h"
#include "sys_common.h"
#include "sys.h"
#include "board.h"



/*------------------------------------------------------------------*
 * Switches use of interrupts on or off, depending on the argument.
 * Switching off the use of interrupts also switches off DMA. The
 * use of interrupts can't be switched on if it wasn't compiled in
 * or the IRQ could not be requested.
 *------------------------------------------------------------------*/

int gpib_set_irq( int state )
{
	PDEBUGin( );

	if ( state != 0 ) {
		if ( board.use_irq )
			board.status |= USE_IRQ;
		else {
			PDEBUG( "Can't switch on use of IRQ\n" );
			gpib_status |= GPIB_ERR;
			gpib_error   = GPIB_ECAP;
			PDEBUGout( );
			return - EINVAL;
		}
	} else
		board.status &= ~ ( USE_IRQ | USE_DMA );

	PDEBUGout( );
	return 0;
}


/*---------------------------------------------------------------------*
 * Interrupt handler function - just does an up() on the transfer
 * semaphore, thereby waking up the process waiting for the interrupt.
 *---------------------------------------------------------------------*/

#if LINUX_VERSION_CODE >= KERNEL_VERSION( 2, 6, 19 )
irqreturn_t gpib_interrupt_handler( int              irq,
				    void *           dev_id )
#elif LINUX_VERSION_CODE >= KERNEL_VERSION( 2, 6, 0 )
irqreturn_t gpib_interrupt_handler( int              irq,
				    void *           dev_id,
				    struct pt_regs * regs )
#else
void gpib_interrupt_handler( int              irq,
			     void *           dev_id,
			     struct pt_regs * regs )
#endif
{
	PDEBUGin( );

#if LINUX_VERSION_CODE < KERNEL_VERSION( 2, 6, 19 )
	regs = regs;                      /* keeps the compiler happy.... */
#endif

	if ( dev_id != &board ) {
		PDEBUG( "IRQ handler called for other device\n" );
		PDEBUGout( );
#if LINUX_VERSION_CODE >= KERNEL_VERSION( 2, 6, 0 )
		return IRQ_NONE;
#else
		return;
#endif
	}

	if ( irq != board.irq ) {        /* did we got the wrong interrupt ? */
		PDEBUG( "Wrong interrupt\n" );
		PDEBUGout( );
#if LINUX_VERSION_CODE >= KERNEL_VERSION( 2, 6, 0 )
		return IRQ_NONE;
#else
		return;
#endif
	}

	if ( ! board.use_irq ) {
#if LINUX_VERSION_CODE >= KERNEL_VERSION( 2, 6, 0 )
		PDEBUG( "Spurious interrupt\n" );
		PDEBUGout( );
		return IRQ_HANDLED;
#else
		PDEBUG( "Spurious for interrupt\n" );
		PDEBUGout( );
		return;
#endif
	}

	PDEBUG( "INTERRUPT\n" );

	up( & ( board.transf.sem ) );    /* wake up the sleeping process */

	PDEBUGout( );

#if LINUX_VERSION_CODE >= KERNEL_VERSION( 2, 6, 0 )
		return IRQ_HANDLED;
#endif
}


/*
 * Local variables:
 * c-basic-offset: 8
 * c-indent-level: 8
 * c-brace-imaginary-offset: 0
 * c-brace-offset: 0
 * c-argdecl-indent: 4
 * c-label-ofset: -4
 * c-continued-statement-offset: 4
 * c-continued-brace-offset: 0
 * indent-tabs-mode: t
 * tab-width: 8
 * End:
 */
