/*
  $Id: gpib_comp.h 736 2006-07-07 15:48:51Z jens $

  Copyright (C) 2001-2006 Jens Thoms Toerring
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
  To contact the author send email to: jt@toerring.de
*/


/**************************************************************************/
/*  Include this header only if you need complete compatibility with the  */
/*  Linux Lab Project or the National Instruments libraries, but expect   */
/*  lots of warnings when compiling !                                     */
/**************************************************************************/


#include "gpib.h"


#ifdef __cplusplus
extern "C" {
#endif


#define ibsta gpib_status
#define iberr gpib_error
#define ibcnt ( unsigned int ) gpib_count


#define ibfind( a )       gpib_find( ( const char * ) ( a ) )
#define ibwrt( a, b, c )  gpib_wrt( ( a ), ( const char * ) ( b ), \
                                    ( size_t ) ( c ) )
#define ibrd( a, b, c )   gpib_rd( ( a ), ( char * ) ( b ), ( size_t ) ( c ) )
#define ibcmd( a, b, c )  gpib_cmd( ( const char * ) ( b ), ( size_t ) ( c ) )

#define ibdev( a, b, c, d, e, f )  \
        gpib_dev( ( a ) , ( b ), ( c ), ( d ), ( ( f ) & 0xFF ), \
                  ( ( ( e ) ? GPIB_EOT : 0 ) | ( ( f ) >> 8 ) ) )
#define ibln( a, b, c, d )  gpib_ln( ( b ), ( c ), ( d ) )

#define ibtmo             gpib_tmo
#define ibpad             gpib_pad
#define ibsad             gpib_sad
#define ibloc             gpib_loc
#define ibllo             gpib_llo
#define ibtrg             gpib_trg
#define ibclr             gpib_clr
#define ibrsp( a, b )     gpib_rsp( ( a ), ( unsigned char ) ( b ) )
#define ibeos             gpib_eos
#define ibonl             gpib_onl
#define ibsre( a, b )     gpib_sre( b )
#define ibgts( a )        gpib_gts( )
#define ibdcl( a )        gpib_dcl( )
#define ibirq( a, b )     gpib_irq( b )
#define ibdma( a, b )     gpib_dma( b )
#define iblines( a, b )   gpib_lines( ( int * ) ( b ) )
#define ibsic( a )        gpib_sic( )


/* gpib_status bits (returned by all functions) */

#define ERR    GPIB_ERR             /* clashes with newer kernels ! */
#define TIMO   GPIB_TIMO
#define END    GPIB_END 
#define SRQI   GPIB_SRQI
#define RQS    GPIB_RQS 
#define CMPL   GPIB_CMPL
#define CIC    GPIB_CIC 
#define ATN    GPIB_ATN 
#define TACS   GPIB_TACS
#define LACS   GPIB_LACS
#define DTAS   GPIB_DTAS
#define DCAS   GPIB_DCAS

/* GPIB_ERR error codes - with the old error codes there is a possibility for
   clashes with libc's namespace because all words beginning with an 'E' and
   followed by a digit or uppercae letter are reserved for future use... */

#define EDVR  GPIB_EDVR
#define ECIC  GPIB_ECIC
#define ENOL  GPIB_ENOL
#define EADR  GPIB_EADR
#define EARG  GPIB_EARG
#define ESAC  GPIB_ESAC
#define EABO  GPIB_EABO
#define ENEB  GPIB_ENEB
#define EDMA  GPIB_EDMA
#define EBTO  GPIB_EBTO
#define EOIP  GPIB_EOIP
#define ECAP  GPIB_ECAP
#define EFSO  GPIB_EFSO
#define EOWN  GPIB_EOWN
#define EBUS  GPIB_EBUS
#define ESTB  GPIB_ESTB
#define ESRQ  GPIB_ESRQ
#define ECFG  GPIB_ECFG
#define EPAR  GPIB_EPAR
#define ETAB  GPIB_ETAB
#define ENSD  GPIB_ENSD
#define ENWE  GPIB_ENWE
#define ENTF  GPIB_ENTF
#define EMEM  GPIB_EMEM

/* End-of-string (EOS) modes for use with gpib_eos() */

#define REOS  GPIB_REOS
#define XEOS  GPIB_XEOS
#define BIN   GPIB_BIN


#ifdef __cplusplus
} /* extern "C" */
#endif


/*
 * Local variables:
 * c-basic-offset: 8
 * c-indent-level: 8
 * c-brace-imaginary-offset: 0
 * c-brace-offset: 0
 * c-argdecl-indent: 4
 * c-label-ofset: -4
 * c-continued-statement-offset: 4
 * c-continued-brace-offset: 0
 * indent-tabs-mode: nil
 * tab-width: 8
 * End:
 */
