/*
  $Id: lexer.l 672 2006-01-19 12:11:17Z jens $

  Copyright (C) 2001-2006 Jens Thoms Toerring
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
  To contact the author send email to: jt@toerring.de
*/


%option noyywrap case-insensitive noinput nounput never-interactive pointer yylineno

%{

#include "lib.h"
#include "parser.h"

int yylex( void );

%}


%x COMMENT
%x CONFIG

CHAR   \'((\\[afnrtv?'"])|.)\'
NAME   \"[^"]+\"
ERR    err(log)?
TIMO   timeout|timo
MASTER controller|master
NOSAD  NO_SAD|no_sad
REOS   (set-)?reos
XEOS   (set-)?xeos
BIN    (set-)?bin
EOT    (set-)?eot
YES    (y(es)?)|(t(rue)?)
NO     (n(o)?)|(f(alse)?)
W      [ \t]


%%         /* Rules */

"/*"                  BEGIN( COMMENT );
<COMMENT>[^*]*
<COMMENT>"*"+[^*/]*
<COMMENT>"*"+"/"      BEGIN( INITIAL );

"device"              return DEVICE_TOKEN;
"name"                return NAME_TOKEN;
"pad"                 return PAD_TOKEN;
"sad"                 return SAD_TOKEN;
"eos"                 return EOS_TOKEN;
"file"                return FILE_TOKEN;
{TIMO}                return TIMO_TOKEN;
{REOS}                return REOS_TOKEN;
{XEOS}                return XEOS_TOKEN;
{BIN}                 return BIN_TOKEN;
{EOT}                 return EOT_TOKEN;
{MASTER}              return MASTER_TOKEN;
{NOSAD}               return NO_SAD_TOKEN;

{YES}                 {
                          yylval.bval = 1;
                          return BOOL_TOKEN;
                      }
{NO}                  {
                          yylval.bval = 0;
                          return BOOL_TOKEN;
                      }
TNONE|none            {
                          yylval.ival = 0;
                          return NUM_TOKEN;
                      }

(T10)|(10{W}*)us      {
                          yylval.ival = 1;
                          return NUM_TOKEN;
                      }
(T30)|(30{W}*)us      {
                          yylval.ival = 2;
                          return NUM_TOKEN;
                      }
(T100)|(100{W}*)us    {
                          yylval.ival = 3;
                          return NUM_TOKEN;
                      }
(T300)|(300{W}*)us    {
                          yylval.ival = 4;
                          return NUM_TOKEN;
                      }
(T1)|(1{W}*)ms        {
                          yylval.ival = 5;
                          return NUM_TOKEN;
                      }
(T3)|(3{W}*)ms        {
                          yylval.ival = 6;
                          return NUM_TOKEN;
                      }
(T10)|(10{W}*)ms      {
                          yylval.ival = 7;
                          return NUM_TOKEN;
                      }
(T30)|(30{W}*)ms      {
                          yylval.ival = 8;
                          return NUM_TOKEN;
                      }
(T100)|(100{W}*)ms    {
                          yylval.ival = 9;
                          return NUM_TOKEN;
                      }
(T300)|(300{W}*)ms    {
                          yylval.ival = 10;
                          return NUM_TOKEN;
                      }
(T1)|(1{W}*)s         {
                          yylval.ival = 11;
                          return NUM_TOKEN;
                      }
(T3)|(3{W}*)s         {
                          yylval.ival = 12;
                          return NUM_TOKEN;
                      }
(T10)|(10{W}*)s       {
                          yylval.ival = 13;
                          return NUM_TOKEN;
                      }
(T30)|(30{W}*)s       {
                          yylval.ival = 14;
                          return NUM_TOKEN;
                      }
(T100)|(100{W}*)s     {
                          yylval.ival = 15;
                          return NUM_TOKEN;
                      }
(T300)|(300{W}*)s     {
                          yylval.ival = 16;
                          return NUM_TOKEN;
                      }
(T1000)|(1000{W}*)s   {
                          yylval.ival = 17;
                          return NUM_TOKEN;
                      }

{CHAR}                {
						  if ( yytext[ 1 ] != '\\' )
						  {
                              yylval.ival = ( int ) yytext[ 1 ];
							  return NUM_TOKEN;
						  }

                          switch ( yytext[ 2 ] ) {
                              case 'a' :
                                  yylval.ival = ( int ) '\a';
                                  break;

                              case 'f' :
                                  yylval.ival = ( int ) '\f';
                                  break;

                              case 'n' :
                                  yylval.ival = ( int ) '\n';
                                  break;

                              case 'r' :
                                  yylval.ival = ( int ) '\r';
                                  break;

                              case 't' :
                                  yylval.ival = ( int ) '\t';
                                  break;

                              case 'v' :
                                  yylval.ival = ( int ) '\v';
                                  break;

                              case '?' :
                                  yylval.ival = ( int ) '\?';
                                  break;

                              case '\'' :
                                  yylval.ival = ( int ) '\'';
                                  break;

                              case '\\' :
                                  yylval.ival = ( int ) '\\';
                                  break;

                              case '"' :
                                  yylval.ival = ( int ) '\"';
                                  break;

                              default :
                                  fprintf( stderr, "Invalid escape sequence "
                                  "at line %d.\n", yylineno );
                                  return ERR_TOKEN;
                          }

                          return NUM_TOKEN;
                      }

0[0-3][0-7]{0,2}      {
                          sscanf( yytext, "%o", &yylval.ival ); 
                          if ( yylval.ival > 255 )
                          {
                              fprintf( stderr, "Integer value too large at "
                                       "line %d.\n", yylineno );
                              return ERR_TOKEN;
                          }
                          return NUM_TOKEN;
                      }
[0-9]|([1-9][0-9])|([1-2][0-9]{2}) {
                          sscanf( yytext, "%d", &yylval.ival ); 
                          if ( yylval.ival > 255 )
                          {
                              fprintf( stderr, "Integer value too large at "
                                       "line %d.\n", yylineno );
                              return ERR_TOKEN;
                          }
                          return NUM_TOKEN;
                      }
0x[0-9A-F]{1,2}       {
                          sscanf( yytext, "0x%x", &yylval.ival );
                          if ( yylval.ival > 255 )
                          {
                              fprintf( stderr, "Integer value too large at "
                                       "line %d.\n", yylineno );
                              return ERR_TOKEN;
                          }
                          return NUM_TOKEN;
                      }

[ \t\n]*              /* Skip white space */

{NAME}                {
                          char *p;
                          yylval.sval = malloc( strlen( yytext ) );
                          strcpy( yylval.sval, yytext + 1 ); 
                          p = yylval.sval;

                          yylval.sval = p;
                          while ( *p != '"' )
                              p++;
                          *p = '\0';
                          return STR_TOKEN;
                      }

.                     return *yytext;

<<EOF>>               return 0;

%%         /* End of rules */
