/*
  $Id: gpib_config_check.c 673 2006-01-19 12:13:02Z jens $

  Copyright (C) 2001-2006 Jens Thoms Toerring
 
  Simple utility to check the syntax of a GPIB configuration file.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  To contact the author send email to: jt@toerring.de
*/


#include "lib.h"

static int parse_config( const char * file );
static void usage( void );
int gpib_dev_setup( Device * dev );

extern int yyparse( void );

int main( int    argc,
		  char * argv[ ] )
{
	const char *cfg;


	if ( argc > 1 )
	{
		if ( ! strcmp( argv[ 1 ], "-h" ) ||
			 ! strcmp( argv[ 1 ], "--h" ) ||
			 ! strcmp( argv[ 1 ], "--help" ) )
			usage( );

		cfg = argv[ 1 ];
	}
	else
	{
		cfg = getenv( "GPIB_CONF" );

		if ( cfg == NULL )
			cfg = GPIB_DEF_CONFIG_FILE;
	}

	return parse_config( cfg  );
}


static int parse_config( const char * file )
{
	extern FILE *yyin;
	FILE *fp;
	int retval;


	if ( ( fp = fopen( file, "r" ) ) == NULL )
	{
		fprintf( stderr, "Failed to open configuration file '%s'.\n", file );
		return EXIT_FAILURE;
	}

	yyin = fp;
	if ( yyparse( ) != 0 )
		retval = EXIT_FAILURE;
	else
	{
		fprintf( stderr, "Syntax of configuration file '%s' is correct.\n",
				 file );
		retval = EXIT_SUCCESS;
	}

	fclose( fp );

	return retval;
}


/* Dummy function - the parser needs it... */

int gpib_dev_setup( Device * dev )
{
	dev = dev;
	return 1;
}


static void usage( void )
{
	fprintf( stderr, "Usage: gpib_config_check [FILE]\n"
			 "Checks the syntax of a GPIB configuration file.\n"
			 "When no file name is given the content of the environment\n"
			 "variable 'GPIB_CONF' is used, and, when it isn't set, the\n"
			 "the default configuration file '/etc/gpib.conf' is checked.\n" );
	exit( EXIT_SUCCESS );
}
