/*
  $Id: parser.y 673 2006-01-19 12:13:02Z jens $

  Copyright (C) 2001-2006 Jens Thoms Toerring
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
  To contact the author send email to: jt@toerring.de
*/


%{

#include "lib.h"


extern int gpib_dev_setup( Device *dev );
extern int yylex( void );
void yyerror( const char *s );

static Device dev;
int dev_line;
extern int yylineno;

%}


%union
{
    bool bval;
    unsigned int ival;
    char *sval;
}


%token DEVICE_TOKEN NAME_TOKEN PAD_TOKEN SAD_TOKEN EOS_TOKEN
%token TIMO_TOKEN REOS_TOKEN XEOS_TOKEN BIN_TOKEN EOT_TOKEN
%token MASTER_TOKEN FILE_TOKEN ERR_TOKEN EN_TOKEN BOOL_TOKEN
%token TIME_TOKEN NUM_TOKEN STR_TOKEN NO_SAD_TOKEN

%type <bval> BOOL_TOKEN bool
%type <ival> NUM_TOKEN sad
%type <sval> STR_TOKEN

%%

line:   /* empty */
      | line device                         { if ( gpib_dev_setup( &dev ) < 0 )
                                                  return -1; }
      | error                               { return -1; }
      | ERR_TOKEN                           { return -1; }
;

device: DEVICE_TOKEN '{'                    { dev_line = yylineno;
		                                      *dev.name   = '\0';
                                              dev.pad     = -1;
                                              dev.pad     = 0;
                                              dev.flags   = 0;
		                                      *dev.file   = '\0'; }
        args '}'
;

args:   /* empty */
      | args NAME_TOKEN sep1 STR_TOKEN sep2 { strncpy( dev.name, $4,
                                                       NAME_MAX + 1 );
                                              free( $4 ); }
      | args PAD_TOKEN sep1 NUM_TOKEN sep2  { dev.pad = $4; }
      | args SAD_TOKEN sep1 sad             { dev.sad = $4; }
      | args EOS_TOKEN sep1 NUM_TOKEN sep2
      | args TIMO_TOKEN sep1 NUM_TOKEN sep2
      | args REOS_TOKEN rt
      | args XEOS_TOKEN xt
      | args BIN_TOKEN bt
      | args EOT_TOKEN et
      | args MASTER_TOKEN mt
      | args FILE_TOKEN sep1 STR_TOKEN sep2 { strncpy( dev.file, $4,
                                                       PATH_MAX + 1 );
                                              free( $4 ); }
	  | args ERR_TOKEN sep1 STR_TOKEN sep2  { free( $4 ); }
;

sad:    NUM_TOKEN sep2                      { $$ = $1; }
      | NO_SAD_TOKEN sep2                   { $$ = NO_SAD; }

mt:     sep2                                { dev.flags |= IS_MASTER; }
      | sep1 bool sep2                      { dev.flags |= $2 * IS_MASTER; }
;

rt:     sep2
      | sep1 bool sep2
;

xt:     sep2
      | sep1 bool sep2
;

bt:     sep2
      | sep1 bool sep2
;

et:     sep2
      | sep1 bool sep2
;

bool:   BOOL_TOKEN                          { $$ = $1; }
      | NUM_TOKEN                           { $$ = $1 ? 1 : 0; }
;

sep1:   /* empty */
      | '='
      | ':'
;

sep2:   /* empty */
      | ','
      | ';'
;


%%


void yyerror( const char * s )
{
    extern char *yytext;

    fprintf( stderr, "%s at token '%s' on line %d.\n", s, yytext, yylineno );
}
